@@ -165,7 +165,7 @@ class VMWorkloadConsolidation(base.ServerConsolidationBaseStrategy):
             cfg.StrOpt(
                 "datasource",
                 help="Data source to use in order to query the needed metrics",
-                default="ceilometer",
+                default="gnocchi",
                 choices=["ceilometer", "gnocchi"])
         ]
 
@@ -228,7 +228,8 @@ class VMWorkloadConsolidation(base.ServerConsolidationBaseStrategy):
         :param node: node object
         :return: None
         """
-        params = {'state': element.ServiceState.DISABLED.value}
+        params = {'state': element.ServiceState.DISABLED.value,
+                  'disabled_reason': self.REASON_FOR_DISABLE}
         self.solution.add_action(
             action_type=self.CHANGE_NOVA_SERVICE_STATE,
             resource_id=node.uuid,
@@ -244,7 +245,8 @@ class VMWorkloadConsolidation(base.ServerConsolidationBaseStrategy):
         :return: None
         """
         instance_state_str = self.get_instance_state_str(instance)
-        if instance_state_str != element.InstanceState.ACTIVE.value:
+        if instance_state_str not in (element.InstanceState.ACTIVE.value,
+                                      element.InstanceState.PAUSED.value):
             # Watcher currently only supports live VM migration and block live
             # VM migration which both requires migrated VM to be active.
             # When supported, the cold migration may be used as a fallback
