@@ -77,14 +77,6 @@ class TestListActionPlan(api_base.FunctionalTest):
               'unit': '%'}],
             response['efficacy_indicators'])
 
-    def test_get_one_with_first_action(self):
-        action_plan = obj_utils.create_test_action_plan(self.context)
-        action = obj_utils.create_test_action(self.context, id=1)
-        response = self.get_json('/action_plans/%s' % action_plan['uuid'])
-        self.assertEqual(action_plan.uuid, response['uuid'])
-        self.assertEqual(action.uuid, response['first_action_uuid'])
-        self._assert_action_plans_fields(response)
-
     def test_get_one_soft_deleted(self):
         action_plan = obj_utils.create_test_action_plan(self.context)
         action_plan.soft_delete()
@@ -136,12 +128,12 @@ class TestListActionPlan(api_base.FunctionalTest):
 
     def test_many_with_soft_deleted_audit_uuid(self):
         action_plan_list = []
-        audit1 = obj_utils.create_test_audit(self.context,
-                                             id=2,
-                                             uuid=utils.generate_uuid())
-        audit2 = obj_utils.create_test_audit(self.context,
-                                             id=3,
-                                             uuid=utils.generate_uuid())
+        audit1 = obj_utils.create_test_audit(
+            self.context, id=2,
+            uuid=utils.generate_uuid(), name='My Audit {0}'.format(2))
+        audit2 = obj_utils.create_test_audit(
+            self.context, id=3,
+            uuid=utils.generate_uuid(), name='My Audit {0}'.format(3))
 
         for id_ in range(0, 2):
             action_plan = obj_utils.create_test_action_plan(
@@ -171,9 +163,9 @@ class TestListActionPlan(api_base.FunctionalTest):
 
     def test_many_with_audit_uuid(self):
         action_plan_list = []
-        audit = obj_utils.create_test_audit(self.context,
-                                            id=2,
-                                            uuid=utils.generate_uuid())
+        audit = obj_utils.create_test_audit(
+            self.context, id=2,
+            uuid=utils.generate_uuid(), name='My Audit {0}'.format(2))
         for id_ in range(2, 5):
             action_plan = obj_utils.create_test_action_plan(
                 self.context, id=id_, uuid=utils.generate_uuid(),
@@ -186,18 +178,18 @@ class TestListActionPlan(api_base.FunctionalTest):
 
     def test_many_with_audit_uuid_filter(self):
         action_plan_list1 = []
-        audit1 = obj_utils.create_test_audit(self.context,
-                                             id=2,
-                                             uuid=utils.generate_uuid())
+        audit1 = obj_utils.create_test_audit(
+            self.context, id=2,
+            uuid=utils.generate_uuid(), name='My Audit {0}'.format(2))
         for id_ in range(2, 5):
             action_plan = obj_utils.create_test_action_plan(
                 self.context, id=id_, uuid=utils.generate_uuid(),
                 audit_id=audit1.id)
             action_plan_list1.append(action_plan.uuid)
 
-        audit2 = obj_utils.create_test_audit(self.context,
-                                             id=3,
-                                             uuid=utils.generate_uuid())
+        audit2 = obj_utils.create_test_audit(
+            self.context, id=3,
+            uuid=utils.generate_uuid(), name='My Audit {0}'.format(3))
         action_plan_list2 = []
         for id_ in [5, 6, 7]:
             action_plan = obj_utils.create_test_action_plan(
@@ -245,9 +237,9 @@ class TestListActionPlan(api_base.FunctionalTest):
     def test_many_with_sort_key_audit_uuid(self):
         audit_list = []
         for id_ in range(2, 5):
-            audit = obj_utils.create_test_audit(self.context,
-                                                id=id_,
-                                                uuid=utils.generate_uuid())
+            audit = obj_utils.create_test_audit(
+                self.context, id=id_,
+                uuid=utils.generate_uuid(), name='My Audit {0}'.format(id_))
             obj_utils.create_test_action_plan(
                 self.context, id=id_, uuid=utils.generate_uuid(),
                 audit_id=audit.id)
@@ -281,8 +273,7 @@ class TestListActionPlan(api_base.FunctionalTest):
         self.assertIn(next_marker, response['next'])
 
     def test_collection_links_default_limit(self):
-        cfg.CONF.set_override('max_limit', 3, 'api',
-                              enforce_type=True)
+        cfg.CONF.set_override('max_limit', 3, 'api')
         for id_ in range(5):
             obj_utils.create_test_action_plan(
                 self.context, id=id_, uuid=utils.generate_uuid())
@@ -322,7 +313,7 @@ class TestDelete(api_base.FunctionalTest):
 
     def test_delete_action_plan_with_action(self):
         action = obj_utils.create_test_action(
-            self.context, id=self.action_plan.first_action_id)
+            self.context, id=1)
 
         self.delete('/action_plans/%s' % self.action_plan.uuid)
         ap_response = self.get_json('/action_plans/%s' % self.action_plan.uuid,
@@ -465,7 +456,7 @@ ALLOWED_TRANSITIONS = [
     {"original_state": objects.action_plan.State.RECOMMENDED,
      "new_state": objects.action_plan.State.CANCELLED},
     {"original_state": objects.action_plan.State.ONGOING,
-     "new_state": objects.action_plan.State.CANCELLED},
+     "new_state": objects.action_plan.State.CANCELLING},
     {"original_state": objects.action_plan.State.PENDING,
      "new_state": objects.action_plan.State.CANCELLED},
 ]
